package
Version:
v0.0.0-...-124b9f8
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: Apache-2.0, MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Permute8(state *[40]byte)
Permute8 applies the 8-round Ascon permutation to a 320-bit state.
func Permute12(state *[40]byte)
Permute12 applies the 12-round Ascon permutation to a 320-bit state.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.