package
Version:
v0.0.0-...-124b9f8
Opens a new window with list of versions in this module.
Published: Feb 25, 2026
License: Apache-2.0, MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Permute(state *[48]byte)
Permute applies the Gimli permutation to a 384-bit state.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.